<?php
/**
 * Banner Options.
 *
 * @package Hait
 */

// Banner Section.
$wp_customize->add_section( 'section_banner',
	array(
		'title'      => esc_html__( 'Banner', 'hait' ),
		'priority'   => 100,
		'panel'      => 'theme_option_panel',
	)
);

// Setting enable_banner.
$wp_customize->add_setting( 'theme_options[enable_banner]',
	array(
		'default'           => $default['enable_banner'],
		'sanitize_callback' => 'hait_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'theme_options[enable_banner]',
	array(
		'label'    			=> esc_html__( 'Enable Banner', 'hait' ),
		'section'  			=> 'section_banner',
		'type'     			=> 'checkbox',
		'priority' 			=> 100,
	)
);

// Setting banner_height.
$wp_customize->add_setting( 'theme_options[banner_height]',
	array(
		'default'           => $default['banner_height'],
		'sanitize_callback' => 'hait_sanitize_positive_integer',
	)
);
$wp_customize->add_control( 'theme_options[banner_height]',
	array(
		'label'       => esc_html__( 'Banner Height', 'hait' ),
		'section'     => 'section_banner',
		'type'        => 'number',
		'priority'    => 100,
		'input_attrs' => array( 'min' => 300, 'max' => 600, 'style' => 'width: 75px;' ),
		'active_callback' 	=> 'hait_is_banner_active',
	)
);

// Setting banner_image_left.
$wp_customize->add_setting( 'theme_options[banner_image_left]',
	array(
		'default'           => $default['banner_image_left'],
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	new WP_Customize_Image_Control(
		$wp_customize,
		'theme_options[banner_image_left]',
		array(
			'label'    => esc_html__( 'Left Image', 'hait' ),
			'section'  => 'section_banner',
			'priority' => 100,
			'active_callback' 	=> 'hait_is_banner_active',
		)
	)
);

// Setting banner_image_right.
$wp_customize->add_setting( 'theme_options[banner_image_right]',
	array(
		'default'           => $default['banner_image_right'],
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	new WP_Customize_Image_Control(
		$wp_customize,
		'theme_options[banner_image_right]',
		array(
			'label'    => esc_html__( 'Right Image', 'hait' ),
			'section'  => 'section_banner',
			'priority' => 100,
			'active_callback' 	=> 'hait_is_banner_active',
		)
	)
);

// Setting banner_heading.
$wp_customize->add_setting( 'theme_options[banner_heading]',
	array(
		'default'           => $default['banner_heading'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'theme_options[banner_heading]',
	array(
		'label'    => esc_html__( 'Heading', 'hait' ),
		'section'  => 'section_banner',
		'type'     => 'text',
		'priority' => 100,
		'active_callback' 	=> 'hait_is_banner_active',
	)
);

// Setting banner_button.
$wp_customize->add_setting( 'theme_options[banner_button]',
	array(
		'default'           => $default['banner_button'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'theme_options[banner_button]',
	array(
		'label'    => esc_html__( 'Button Text', 'hait' ),
		'section'  => 'section_banner',
		'type'     => 'text',
		'priority' => 100,
		'active_callback' 	=> 'hait_is_banner_active',
	)
);

// Setting banner_link.
$wp_customize->add_setting( 'theme_options[banner_link]',
	array(
		'default'           => $default['banner_link'],
		'sanitize_callback' => 'sanitize_url',
	)
);
$wp_customize->add_control( 'theme_options[banner_link]',
	array(
		'label'    => esc_html__( 'Button Link', 'hait' ),
		'section'  => 'section_banner',
		'type'     => 'text',
		'priority' => 100,
		'active_callback' 	=> 'hait_is_banner_active',
	)
);
