<?php
/**
 * Blog Options.
 *
 * @package Hait
 */

// Blog Section.
$wp_customize->add_section( 'section_blog',
	array(
		'title'      => esc_html__( 'Blog/Archive', 'hait' ),
		'priority'   => 100,
		'panel'      => 'theme_option_panel',
	)
);

// Setting content_width.
$wp_customize->add_setting( 'theme_options[content_width]',
	array(
		'default'           => $default['content_width'],
		'sanitize_callback' => 'hait_sanitize_positive_integer',
	)
);
$wp_customize->add_control( 'theme_options[content_width]',
	array(
		'label'    => esc_html__( 'Content Width', 'hait' ),
		'section'  => 'section_blog',
		'type'     => 'number',
		'priority' => 100,
		'input_attrs' => array( 'min' => 700, 'max' => 1280, 'style' => 'width: 75px;' ),
	)
);

// Setting global_layout.
$wp_customize->add_setting( 'theme_options[global_layout]',
	array(
		'default'           => $default['global_layout'],
		'sanitize_callback' => 'hait_sanitize_select',
	)
);
$wp_customize->add_control( 'theme_options[global_layout]',
	array(
		'label'    => esc_html__( 'Default Layout', 'hait' ),
		'section'  => 'section_blog',
		'type'     => 'radio',
		'priority' => 100,
		'choices'  => array(
				'list'  => esc_html__( 'List', 'hait' ),
				'grid' => esc_html__( 'Grid', 'hait' ),
				'list-grid' => esc_html__( 'First Full + Grid', 'hait' ),
			),
	)
);

// Setting grid_number.
$wp_customize->add_setting( 'theme_options[grid_number]',
	array(
		'default'           => $default['grid_number'],
		'sanitize_callback' => 'hait_sanitize_positive_integer',
	)
);
$wp_customize->add_control( 'theme_options[grid_number]',
	array(
		'label'    => esc_html__( 'Gird Column', 'hait' ),
		'section'  => 'section_blog',
		'type'     => 'number',
		'priority' => 100,
		'input_attrs' => array( 'min' => 2, 'max' => 3, 'style' => 'width: 55px;' ),
		'active_callback' 	=> 'hait_is_layout_grid_active',
	)
);

// Setting show_date.
$wp_customize->add_setting( 'theme_options[show_date]',
	array(
		'default'           => $default['show_date'],
		'sanitize_callback' => 'hait_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'theme_options[show_date]',
	array(
		'label'    			=> esc_html__( 'Show Date', 'hait' ),
		'section'  			=> 'section_blog',
		'type'     			=> 'checkbox',
		'priority' 			=> 100,
	)
);

// Setting show_author.
$wp_customize->add_setting( 'theme_options[show_author]',
	array(
		'default'           => $default['show_author'],
		'sanitize_callback' => 'hait_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'theme_options[show_author]',
	array(
		'label'    			=> esc_html__( 'Show Author', 'hait' ),
		'section'  			=> 'section_blog',
		'type'     			=> 'checkbox',
		'priority' 			=> 100,
	)
);

// Setting show_categories.
$wp_customize->add_setting( 'theme_options[show_categories]',
	array(
		'default'           => $default['show_categories'],
		'sanitize_callback' => 'hait_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'theme_options[show_categories]',
	array(
		'label'    			=> esc_html__( 'Show Categories', 'hait' ),
		'section'  			=> 'section_blog',
		'type'     			=> 'checkbox',
		'priority' 			=> 100,
	)
);

// Setting show_excerpt.
$wp_customize->add_setting( 'theme_options[show_excerpt]',
	array(
		'default'           => $default['show_excerpt'],
		'sanitize_callback' => 'hait_sanitize_checkbox',
	)
);
$wp_customize->add_control( 'theme_options[show_excerpt]',
	array(
		'label'    			=> esc_html__( 'Show Excerpt', 'hait' ),
		'section'  			=> 'section_blog',
		'type'     			=> 'checkbox',
		'priority' 			=> 100,
	)
);

// Setting excerpt_length.
$wp_customize->add_setting( 'theme_options[excerpt_length]',
	array(
		'default'           => $default['excerpt_length'],
		'sanitize_callback' => 'hait_sanitize_positive_integer',
	)
);
$wp_customize->add_control( 'theme_options[excerpt_length]',
	array(
		'label'       => esc_html__( 'Excerpt Length', 'hait' ),
		'section'     => 'section_blog',
		'type'        => 'number',
		'priority'    => 100,
		'input_attrs' => array( 'min' => 1, 'max' => 200, 'style' => 'width: 55px;' ),
		'active_callback' 	=> 'hait_is_show_excerpt_active',
	)
);

// Setting readmore_text.
$wp_customize->add_setting( 'theme_options[readmore_text]',
	array(
		'default'           => $default['readmore_text'],
		'sanitize_callback' => 'sanitize_text_field',
	)
);
$wp_customize->add_control( 'theme_options[readmore_text]',
	array(
		'label'    => esc_html__( 'Read More Text', 'hait' ),
		'section'  => 'section_blog',
		'type'     => 'text',
		'priority' => 100,
		'active_callback' 	=> 'hait_is_show_excerpt_active',
	)
);
