<?php
/**
 * Dynamic Options hook.
 *
 * This file contains option values from customizer
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Hait
 */

if ( ! function_exists( 'hait_dynamic_styles' ) ) :
	function hait_dynamic_styles() {

		$custom_css = "";

		/*--------------------------------------------------------------
		## Logo Height
		--------------------------------------------------------------*/
		$logo_height =  hait_get_option( 'logo_height' );

		$custom_css .= "
		.site-branding img {
		  max-height: {$logo_height}px;
		  width: auto;
		}";

		/*--------------------------------------------------------------
		## Banner Height
		--------------------------------------------------------------*/
		$banner_height =  hait_get_option( 'banner_height' );
		$banner_height_mobile = $banner_height / 2;

		$custom_css .= "
		.featured-banner .banner-item {
		  min-height: {$banner_height}px;
		}";

		$custom_css .= "
		@media only screen and (max-width:767px) {
			.featured-banner .banner-item {
			  min-height: {$banner_height_mobile}px;
			}
		}";

		/*--------------------------------------------------------------
		## Content Width Archive
		--------------------------------------------------------------*/
		$content_width =  hait_get_option( 'content_width' );

		$custom_css .= "
		.home.blog .site-main,
		.blog .site-main,
		.archive .site-main {
		  max-width: {$content_width}px;
		  margin: 0 auto;
		}";

		/*--------------------------------------------------------------
		## Content Width Single
		--------------------------------------------------------------*/
		$content_width_single =  hait_get_option( 'content_width_single' );

		$custom_css .= "
		.single .site-main {
		  max-width: {$content_width_single}px;
		  margin: 0 auto;
		}";

		/*--------------------------------------------------------------
		## Shop Width Archive
		--------------------------------------------------------------*/
		$shop_content_width =  hait_get_option( 'shop_content_width' );

		$custom_css .= "
		.archive.woocommerce-shop .site-main,
		.archive.tax-product_cat .site-main {
			max-width: {$shop_content_width}px;
		}";

		/*--------------------------------------------------------------
		## Shop Width Single
		--------------------------------------------------------------*/
		$shop_content_width_single =  hait_get_option( 'shop_content_width_single' );

		$custom_css .= "
		.single.single-product .site-main {
			max-width: {$shop_content_width_single}px;
		}";

		wp_add_inline_style( 'hait-style', $custom_css );
	}
endif;

add_action( 'wp_enqueue_scripts', 'hait_dynamic_styles' );

